
clear;


% example script to generate soundscapes for experiment 3

%------------------------------------------------------------
% init parameters for Set 3
ARG.dots.ndots       = 30;  % number of tone sequences
ARG.Rate = 44100;
ARG.dots.StimDur     = 1.2;  % duration in sec
ARG.dots.max_f       = 14;   % maximum stimulus freq [2.^x]
ARG.dots.min_f       = 7;    % minumum stimulus freq
ARG.dots.dot_speed   =0.05;    % stepsize for freq increase or decrease [in proportion to f0]
ARG.dots.MaxLife = 4; % life time of each tone sequence (multiples of dot_dur)
ARG.dots.dot_dur = 0.030; % duration of each tone [s]

ARG.dots.PULSE_DUR = 4; % duration of each 'epoch' with fixed coherence. Is a multiple of tone duration
% ->> Between epochs the coherence is randomized -> sets the time scale of the psychophysical kernel

ARG.dots.SD = 0.25; % SD of pulse by pulse coherence around mean coherence value
ARG.dots.nframes = ceil(ARG.dots.StimDur/ARG.dots.dot_dur)+3; % number of frames to create.
ARG.dots.scale = 0.07; % scaling factor for intensity. unimportant

%------------------------------------------------------------
% create soundscape
% for a given coherence and direction
curr_coh = 0.8; % [0 to 1]. Here we simulate a reasonably clear melody.
curr_direction = 1; % 1) up, 2) down
Make_tones_sim;
% this returns the sensory evidence time course

% ------------------------------------------------------------------------
% now we create the actual sound wave

totdur = round(ARG.dots.nframes*ARG.dots.dot_dur*ARG.Rate); % pre-allocation of waveform vector in samples
dursnd = round(ARG.Rate*ARG.dots.StimDur); % actual duration required
Stim = zeros(ARG.dots.ndots,dursnd);

for d=1:ARG.dots.ndots % each tone ID
  tmp=[];
  t = [1:round(ARG.dots.dot_dur*ARG.Rate)]/ARG.Rate;
  for f=1:ARG.dots.nframes
    tone = sin(t*2*pi*2.^f0(f,d)) ;
    tone = cosine_ramp(tone,0.006,ARG.Rate);
    tmp = cat(2,tmp,tone);
  end
  % add random offset for each tone so that the timing of each tone sequence is random
  offset = round(rand*ARG.dots.dot_dur*ARG.Rate)+1;
  tmp = tmp(offset:end);
  Stim(d,:) = cosine_ramp(tmp([1:dursnd]),0.006,ARG.Rate);
end

SND = mean(Stim)/std(mean(Stim))*ARG.dots.scale;

% -> PLAY
soundsc(SND,ARG.Rate)

% Display  evidence
figure

time_ax = [1:(ARG.dots.nframes-3)]*0.03;
plot(time_ax,Motion_list(1:end-3)); % because we create 3 frames in addition to the desired length
xlabel('Time [s]');

